@@ -19,9 +19,6 @@ MDplot = PDEviolinPlot = function(Data, Names, Ordering='Default',Scaling="None"
   #always required:
   requireNamespace("reshape2")
 
-
-  
- 
   ## Error Catching ----
   if (is.vector(Data)) {
     print("This MD-plot is typically for several features at once. By calling as.matrix(), it will be now used with one feature.")
@@ -44,14 +41,14 @@ MDplot = PDEviolinPlot = function(Data, Names, Ordering='Default',Scaling="None"
   })
   if(any(Nfinitepervar<1)){
     warning('Some columns have not even one finite value. Please check your data. Deleting these columns.')
-    Data=Data[,Nfinitepervar>0]
+    Data=Data[,Nfinitepervar>0,drop=FALSE]
     dvariables=ncol(Data)
   }
   
   if(Ncases>SampleSize){
     warning('Data has more cases than "SampleSize". Drawing a sample for faster computation.
             You can omit this by setting "SampleSize=nrow(Data".')
-    if(isTRUE(requireNamespace('rowr'))){
+    #if(isTRUE(requireNamespace('rowr'))){
     #here only finite values are sampled
     indmat=matrix(0,nrow = SampleSize,ncol = dvariables)
     for(i in 1:dvariables){
@@ -65,18 +62,18 @@ MDplot = PDEviolinPlot = function(Data, Names, Ordering='Default',Scaling="None"
     DataListtemp=mapply(FUN = function(x,y) return(x[y]), as.list(as.data.frame(Data))
                 ,as.list(as.data.frame(indmat)),SIMPLIFY = FALSE)
     
-    addcols=function(...){
-      return(rowr::cbind.fill(...,fill = NaN))
-    }
+    #addcols=function(...){
+    #  return(cbind_fill(...,fill = NaN))
+    #}
     nn=colnames(Data)
     Data=do.call(addcols,DataListtemp)
     colnames(Data)=nn
     Data=as.matrix(Data)
-    }else{#here alle vectors are sampled
-      warning('Package rowr is not installed. Sampling Data without taking finite values only into account.')
-      ind=sample(1:Ncases,size = SampleSize)
-      Data=Data[ind,,drop=FALSE]
-    }
+    #}else{#here alle vectors are sampled
+   #   warning('Package rowr is not installed. Sampling Data without taking finite values only into account.')
+    #  ind=sample(1:Ncases,size = SampleSize)
+    #  Data=Data[ind,,drop=FALSE]
+    #}
     Ncases=nrow(Data)
   }
 
@@ -312,10 +309,58 @@ MDplot = PDEviolinPlot = function(Data, Names, Ordering='Default',Scaling="None"
          },
          Columnwise={Rangfolge=Rangfolge},
          Alphabetical={Rangfolge=sort(Rangfolge,decreasing = F,na.last = T)},
+         Average={
+           x=as.matrix(Data)
+           med_val=apply(x,2,median,na.rm=TRUE)
+           meanval=apply(x,2,function(x) {
+             x=x[is.finite(x)]
+             if(length(x)>0){
+               y=mean(x,trim = 0.1)
+               return(y)
+             }else{
+               return(0)
+             }
+           })
+           average_vals=(med_val+meanval)/2 #weighted average
+           average_ind=order(average_vals,na.last = T,decreasing = FALSE)
+           Rangfolge=Rangfolge[average_ind]
+           },
+         Variance={
+           x=as.matrix(Data)
+           iqr_vals=apply(x,2,function(x) {
+             x=x[is.finite(x)]
+             if(length(x)>0){
+               y=c_quantile(x,c(0.25,0.75))
+               iqr=y[2]-y[1]
+               return(iqr)
+             }else{
+               return(0)
+             }
+           })
+           iqr_ind=order(iqr_vals,na.last = T,decreasing = FALSE)
+           Rangfolge=Rangfolge[iqr_ind]
+         },
+         Bimodal={
+           x=as.matrix(Data)
+           requireNamespace('modes')
+           bimodalitycoef=apply(x,2,function(x) {
+             x=x[is.finite(x)]
+             if(length(x)>0){
+               y=modes::bimodality_amplitude(x,fig=FALSE)
+               if(identical(y, numeric(0))) y=0
+               return(y)
+             }else{
+               return(0)
+             }
+             }
+             )
+           bimodal_ind=order(bimodalitycoef,na.last = T,decreasing = TRUE)
+           Rangfolge=Rangfolge[bimodal_ind]
+         },
          Statistics={
            Rangfolge=Rangfolge[order(Effectstrength,decreasing = T,na.last = T)]
          },
-         {stop('You can select for Ordering: "Default", "Columnwise", "Alphabetical" or "Statistics"')}
+         {stop('You can select for Ordering: "Default", "Columnwise", "Alphabetical", "Average", "Bimodal", "Variance" or "Statistics"')}
   )
 
   ## Data Reshaping----
